@@ -2,18 +2,18 @@ OC.L10N.register(
     "tasks",
     {
     "Tasks" : "Úkoly",
-    "Due yesterday" : "Vypršelo včera",
-    "Due today" : "Vyprší dnes",
-    "Due tomorrow" : "Vyprší zítra",
-    "Due on" : "Vyprší",
+    "Due yesterday" : "Termín byl včera",
+    "Due today" : "Termín je dnes",
+    "Due tomorrow" : "Termín zítra",
+    "Due on" : "Platnost skončí",
     "Started yesterday" : "Začalo včera",
     "Starts today" : "Začíná dnes",
     "Starts tomorrow" : "Začne zítra",
     "Started on" : "Začalo",
     "Starts on" : "Začíná",
     "[Remind me yesterday at ]HH:mm" : "[Připomeň mi včera v ]HH:mm",
-    "[Remind me today at ]HH:mm" : "[Připomeň mi dnes v ]HH:mm",
-    "[Remind me tomorrow at ]HH:mm" : "[Připomeň mi zítra v ]HH:mm",
+    "[Remind me today at ]HH:mm" : "[Připomenout mi dnes v ]HH:mm",
+    "[Remind me tomorrow at ]HH:mm" : "[Připomenout mi zítra v ]HH:mm",
     "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Připomeň mi v ]MMM DD, YYYY,[ v ]HH:mm",
     "Yesterday" : "Včera",
     "Today" : "Dnes",
@@ -64,7 +64,7 @@ OC.L10N.register(
     "Add an item in \"%s\"..." : "Přidat položku do \"%s\"...",
     "Add a current item in \"%s\"..." : "Přidat současnou položku do \"%s\"...",
     "Add a subtask to \"%s\"..." : "Přidat podúkol k \"%s\"...",
-    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončený úkol","%n dokončené úkoly","%n dokončených úkolů"],
+    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončený úkol","%n dokončené úkoly","%n dokončených úkolů","%n dokončených úkolů"],
     "Hours" : "Hodiny",
     "Minutes" : "Minuty",
     "Set due date" : "Nastavit datum vypršení",
@@ -114,4 +114,4 @@ OC.L10N.register(
     "Toggle subtasks" : "Přepnout podúkoly",
     "Toggle completed subtasks" : "Přepnout dokončené podúkoly"
 },
-"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
+"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
