@@ -104,11 +104,14 @@ OC.L10N.register(
     "Alphabetically" : "Αλφαβητικά",
     "Manually" : "Χειροκίνητα",
     "Load remaining completed tasks." : "Φόρτωση απομένοντων ολοκληρωμένων εργασιών",
+    "Task is completed" : "Η εργασία ολοκληρώθηκε",
     "All day" : "Ολοήμερο",
     "(New category)" : "(Νέα κατηγορία)",
     "Select categories..." : "Επιλογή κατηγοριών...",
     "Loading the task..." : "Φόρτωση της εργασίας...",
     "Task not found!" : "Δεν βρέθηκε εργασία!",
-    "add a subtask to" : "προσθήκη υποέργου σε"
+    "add a subtask to" : "προσθήκη υποέργου σε",
+    "Toggle subtasks" : "Εναλλαγή υποεργασιών",
+    "Toggle completed subtasks" : "Εναλλαγή ολοκληρωμένων υποεργασιών"
 },
 "nplurals=2; plural=(n != 1);");
