@@ -64,7 +64,7 @@ OC.L10N.register(
     "Add an item in \"%s\"..." : "הוספת פריט ב־\"%s\"...",
     "Add a current item in \"%s\"..." : "הוספת פריט נוכחי ב־\"%s\"...",
     "Add a subtask to \"%s\"..." : "הוספת תת־פעילות ל־\"%s\"...",
-    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו"],
+    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
     "Hours" : "שעות",
     "Minutes" : "דקות",
     "Set due date" : "הגדרת תאריך יעד",
@@ -85,6 +85,7 @@ OC.L10N.register(
     "All" : "הכול",
     "Current" : "נוכחי",
     "Completed" : "הושלם",
+    "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
     "Delete" : "מחיקה",
     "Cancel" : "ביטול",
     "Edit" : "עריכה",
@@ -114,4 +115,4 @@ OC.L10N.register(
     "Toggle subtasks" : "הפעלה/כיבוי של תת־משימות",
     "Toggle completed subtasks" : "הפעלה/כיבוי של תת־משימות שהושלמו"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
