@@ -59,11 +59,11 @@ OC.L10N.register(
     "Thursday" : "Czwartek",
     "Friday" : "Piątek",
     "Saturday" : "Sobota",
-    "Add an important item in \"%s\"..." : "Dodaj ważny element w \"%s\" ...",
-    "Add an item due today in \"%s\"..." : "Dodaj element na dzisiaj w \"%s\" ...",
-    "Add an item in \"%s\"..." : "Dodaj element w \"%s\" ...",
-    "Add a current item in \"%s\"..." : "Dodaj aktualny element w \"%s\" ...",
-    "Add a subtask to \"%s\"..." : "Dodaj podzadanie do \"%s\"...",
+    "Add an important item in \"%s\"..." : "Dodaj ważny element w \"%s\"…",
+    "Add an item due today in \"%s\"..." : "Dodaj element na dzisiaj w \"%s\"…",
+    "Add an item in \"%s\"..." : "Dodaj element w \"%s\"…",
+    "Add a current item in \"%s\"..." : "Dodaj aktualny element w \"%s\"…",
+    "Add a subtask to \"%s\"..." : "Dodaj podzadanie do \"%s\"…",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n zakończone zadanie","%n zakończonych zadań","%n zakończonych zadań","%n zakończonych zadań"],
     "Hours" : "Godzin",
     "Minutes" : "Minut",
@@ -85,13 +85,14 @@ OC.L10N.register(
     "All" : "Wszystkie",
     "Current" : "Obecny",
     "Completed" : "Ukończono",
+    "The Tasks app for Nextcloud" : "Aplikacja Zadania dla Nextcloud",
     "Delete" : "Usuń",
     "Cancel" : "Anuluj",
     "Edit" : "Edytuj",
     "Link" : "Link",
     "Download" : "Pobierz",
     "Save" : "Zapisz",
-    "Add List..." : "Dodaj listę...",
+    "Add List..." : "Dodaj listę…",
     "New List" : "Nowa lista",
     "Settings" : "Ustawienia",
     "Start of week" : "Początek tygodnia",
@@ -107,8 +108,8 @@ OC.L10N.register(
     "Task is completed" : "Zadanie jest zakończone",
     "All day" : "Cały dzień",
     "(New category)" : "(Nowa kategoria)",
-    "Select categories..." : "Wybierz kategorie...",
-    "Loading the task..." : "Ładowanie zadania...",
+    "Select categories..." : "Wybierz kategorie…",
+    "Loading the task..." : "Ładowanie zadania…",
     "Task not found!" : "Nie znaleziono zadania!",
     "add a subtask to" : "dodaj podzadanie do",
     "Toggle subtasks" : "Przełącz podzadania",
