@@ -73,7 +73,7 @@ OC.L10N.register(
     "high" : "visoka",
     "medium" : "srednja",
     "low" : "nizka",
-    "no priority assigned" : "prednost ni določena",
+    "no priority assigned" : "ni določena",
     "Remind me" : "Opomni me",
     "at the end" : "na koncu",
     "at the beginning" : "na začetku",
@@ -85,6 +85,7 @@ OC.L10N.register(
     "All" : "Vsi",
     "Current" : "Trenutno",
     "Completed" : "Končano",
+    "The Tasks app for Nextcloud" : "Program Tasks za Nextcloud",
     "Delete" : "Izbriši",
     "Cancel" : "Prekliči",
     "Edit" : "Uredi",
